import { resolveComponent as p, openBlock as r, createElementBlock as d, normalizeClass as _, createElementVNode as s, normalizeStyle as l, withModifiers as c, createBlock as m, Fragment as v, createTextVNode as y, toDisplayString as f } from "vue";
import { _ as g } from "./_plugin-vue_export-helper.e9cbb45e.mjs";
import { u as a } from "./index.673e51a0.mjs";
const P = {
  props: {
    min: {
      type: Number,
      default: 0
    },
    max: {
      type: Number,
      default: 100
    },
    modelValue: {
      type: Object,
      default: () => ({})
    },
    decimals: {
      type: Number,
      default: 0,
      validator(e) {
        return e >= 0;
      }
    },
    step: {
      type: Number,
      default: 1,
      validator(e) {
        return e > 0;
      }
    },
    invalid: {
      type: Boolean,
      default: !1
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    loading: {
      type: Boolean,
      default: !1
    }
  },
  emits: ["update:modelValue"],
  data() {
    return {
      trackX: 0,
      trackWidth: 0,
      primaryPosition: 0,
      secondaryPosition: 0
    };
  },
  computed: {
    classNames() {
      return {
        "lv-range-slider--invalid": this.invalid,
        "lv-range-slider--disabled": this.disabled,
        "lv-range-slider--loading": this.loading
      };
    },
    primaryValue() {
      const e = (this.max - this.min) / 100 * this.primaryPosition + this.min;
      return parseFloat(e.toFixed(this.decimals));
    },
    secondaryValue() {
      const e = (this.max - this.min) / 100 * this.secondaryPosition + this.min;
      return parseFloat(e.toFixed(this.decimals));
    },
    indicatorLeft() {
      return this.primaryPosition <= this.secondaryPosition ? this.primaryPosition : this.secondaryPosition;
    },
    indicatorRight() {
      return this.primaryPosition >= this.secondaryPosition ? this.primaryPosition : this.secondaryPosition;
    },
    stepPercentage() {
      return 100 / (this.max - this.min) * this.step;
    }
  },
  watch: {
    modelValue: {
      handler(e) {
        this.primaryPosition = e.from ? this.getPositionFromValue(e.from) : 0, this.secondaryPosition = e.to ? this.getPositionFromValue(e.to) : 100;
      },
      deep: !0,
      immediate: !0
    }
  },
  mounted() {
    this.cacheDimensions();
  },
  created() {
    this.onPrimaryMouseMoveThrottled = a(this.onPrimaryMouseMove, 25, !1), this.onSecondaryMouseMoveThrottled = a(this.onSecondaryMouseMove, 25, !1), this.onPrimaryTouchMoveThrottled = a(this.onPrimaryTouchMove, 25, !1), this.onSecondaryTouchMoveThrottled = a(this.onSecondaryTouchMove, 25, !1);
  },
  methods: {
    onPrimaryMouseDown() {
      this.disabled || this.loading || (this.cacheDimensions(), document.addEventListener("mousemove", this.onPrimaryMouseMoveThrottled, !1), document.addEventListener("mouseup", this.onMouseUp, !1));
    },
    onPrimaryMouseMove(e) {
      this.primaryPosition = this.getRelativePosition(e.pageX);
    },
    onSecondaryMouseDown() {
      this.disabled || this.loading || (this.cacheDimensions(), document.addEventListener("mousemove", this.onSecondaryMouseMoveThrottled, !1), document.addEventListener("mouseup", this.onMouseUp, !1));
    },
    onSecondaryMouseMove(e) {
      this.secondaryPosition = this.getRelativePosition(e.pageX);
    },
    onMouseUp() {
      document.removeEventListener("mousemove", this.onPrimaryMouseMoveThrottled, !1), document.removeEventListener("mousemove", this.onSecondaryMouseMoveThrottled, !1), document.removeEventListener("mouseup", this.onMouseUp, !1), this.emitInputEvent();
    },
    onPrimaryTouchStart() {
      this.disabled || (this.cacheDimensions(), document.addEventListener("touchmove", this.onPrimaryTouchMoveThrottled), document.addEventListener("touchend", this.onTouchEnd));
    },
    onPrimaryTouchMove(e) {
      e.preventDefault(), this.primaryPosition = this.getRelativePosition(e.touches[0].clientX);
    },
    onSecondaryTouchStart() {
      this.disabled || (this.cacheDimensions(), document.addEventListener("touchmove", this.onSecondaryTouchMoveThrottled), document.addEventListener("touchend", this.onTouchEnd));
    },
    onSecondaryTouchMove(e) {
      e.preventDefault(), this.secondaryPosition = this.getRelativePosition(e.touches[0].clientX);
    },
    onTouchEnd() {
      document.removeEventListener("touchmove", this.onPrimaryTouchMoveThrottled), document.removeEventListener("touchmove", this.onSecondaryTouchMoveThrottled), document.removeEventListener("touchend", this.onTouchEnd), this.emitInputEvent();
    },
    emitInputEvent() {
      const e = this.primaryValue <= this.secondaryValue ? this.primaryValue : this.secondaryValue, o = this.primaryValue <= this.secondaryValue ? this.secondaryValue : this.primaryValue;
      this.$emit("update:modelValue", {
        from: e,
        to: o
      });
    },
    cacheDimensions() {
      this.trackWidth = this.$refs.track.offsetWidth, this.trackX = this.$refs.track.getBoundingClientRect().left;
    },
    getPositionFromValue(e) {
      return 100 / (this.max - this.min) * e - this.min / (this.max - this.min) * 100;
    },
    getRelativePosition(e) {
      let i = (e - this.trackX) / this.trackWidth * 100;
      return this.step && (i = Math.round(i / this.stepPercentage) * this.stepPercentage), i = Math.min(Math.max(i, 0), 100), i;
    }
  }
}, M = { class: "lv-range-slider__track" }, T = {
  ref: "track",
  class: "lv-range-slider__track-limits"
}, S = { class: "lv-range-slider__amounts" }, E = { class: "lv-range-slider__amount lv-range-slider__amount--primary" }, V = { class: "lv-range-slider__amount lv-range-slider__amount--secondary" };
function k(e, o, i, L, h, t) {
  const u = p("lv-icon");
  return r(), d("div", {
    class: _(["lv-range-slider", t.classNames])
  }, [
    s("div", M, [
      s("div", T, [
        s("div", {
          class: "lv-range-slider__indicator",
          style: l({ left: t.indicatorLeft + "%", right: 100 - t.indicatorRight + "%" })
        }, null, 4),
        s("div", {
          ref: "primary",
          class: "lv-range-slider__thumb lv-range-slider__thumb--primary",
          style: l({ left: h.primaryPosition + "%" }),
          onMousedown: o[0] || (o[0] = c((...n) => t.onPrimaryMouseDown && t.onPrimaryMouseDown(...n), ["prevent"])),
          onTouchstart: o[1] || (o[1] = (...n) => t.onPrimaryTouchStart && t.onPrimaryTouchStart(...n))
        }, null, 36),
        s("div", {
          ref: "secondary",
          class: "lv-range-slider__thumb lv-range-slider__thumb--secondary",
          style: l({ left: h.secondaryPosition + "%" }),
          onMousedown: o[2] || (o[2] = c((...n) => t.onSecondaryMouseDown && t.onSecondaryMouseDown(...n), ["prevent"])),
          onTouchstart: o[3] || (o[3] = (...n) => t.onSecondaryTouchStart && t.onSecondaryTouchStart(...n))
        }, null, 36)
      ], 512)
    ]),
    s("div", S, [
      s("div", E, [
        i.loading ? (r(), m(u, {
          key: 0,
          class: "lv-range-slider__loader",
          size: 12,
          name: "loader-2"
        })) : (r(), d(v, { key: 1 }, [
          y(f(t.primaryValue.toFixed(i.decimals)), 1)
        ], 64))
      ]),
      s("div", V, [
        i.loading ? (r(), m(u, {
          key: 0,
          class: "lv-range-slider__loader",
          size: 12,
          name: "loader-2"
        })) : (r(), d(v, { key: 1 }, [
          y(f(t.secondaryValue.toFixed(i.decimals)), 1)
        ], 64))
      ])
    ])
  ], 2);
}
const F = /* @__PURE__ */ g(P, [["render", k]]);
export {
  F as default
};
